@@ -5,9 +5,9 @@ from typing import Union
 
 from django.conf import settings
 from django.contrib.auth import get_user_model
-from rest_framework import status
-from rest_framework.exceptions import APIException
 from rest_framework_simplejwt.tokens import RefreshToken
+from google.auth.transport.requests import Request
+from google.oauth2 import id_token
 
 from expressmoney import utils
 
@@ -15,12 +15,6 @@ from expressmoney import utils
 User = get_user_model()
 
 
-class ClientError(APIException):
-    status_code = status.HTTP_400_BAD_REQUEST
-    default_detail = 'Invalid request from client.'
-    default_code = 'client_error'
-
-
 def get_ip(request):
     """Get client ip from header"""
     x_forwarded_for = request.META.get('HTTP_X_FORWARDED_FOR', None)
@@ -85,8 +79,6 @@ class DjangoRequest(utils.Request):
         super().__init__(service, path, access_token, project, timeout)
 
     def _get_authorization(self) -> dict:
-        from google.auth.transport.requests import Request
-        from google.oauth2 import id_token
         authorization = super()._get_authorization()
         open_id_connect_token = id_token.fetch_id_token(Request(), settings.IAP_CLIENT_ID)
         iap_token = {'Authorization': f'Bearer {open_id_connect_token}'}
